@@ -102,17 +102,10 @@ indexing_subsets_no100 <- function(
   return(nested_list)
 }
 
-sample_percents = c(25, 50, 75, 100)
-handle_word_embeddings = "individually"
-n_cross_val = 1
-sampling_strategy = "subsets"
-use_same_penalty_mixture = TRUE
-model = "regression"
-penalty = 10^seq(1, -1)
-mixture = c(0)
-seed = 2024
 #### textTrainN function ####
-#' (experimental) Compute cross-validated correlations for different sample-sizes of a data set.
+#' Cross-validated accuracies across sample-sizes
+#'
+#' textTrainN() computes cross-validated correlations for different sample-sizes of a data set.
 #' The cross-validation process can be repeated several times to enhance the reliability of the evaluation.
 #' @param x Word embeddings from textEmbed (or textEmbedLayerAggregation).
 #' If several word embedding are provided in a list they will be concatenated.
@@ -338,8 +331,8 @@ textTrainN <- function(
       }
       saving_models[check][[idx]] <- trained
 
-      print(paste("check:", check))
-      print(paste("idx:", idx))
+      message(paste("check:", check))
+      message(paste("idx:", idx))
       # Extract the correlation-coefficient or AUC and assign it to results_df
       if (model == "logistic" || model == "multinomial") {
         value_to_insert <- trained$results[8, 3]
@@ -364,12 +357,12 @@ textTrainN <- function(
         check_time_start <- check_time_2 - check_time_0
         check_time <- check_time_2 - check_time_1
         # Print progress
-        print(results_df)
-        print(paste0("Computing time from the start: ",
+        message(results_df)
+        message(paste0("Computing time from the start: ",
                      round(check_time_start, 2),
                      units(check_time_start)))
 
-        print(paste0("Computing time since starting the current test column: ",
+        message(paste0("Computing time since starting the current test column: ",
                      round(check_time, 2),
                      units(check_time)))
       }
@@ -444,11 +437,11 @@ textTrainN <- function(
   results_df <- tibble::as_tibble(results_df)
 
   # Print progress
-  print(results_df)
+  message(results_df)
   check_time_3 <- Sys.time()
   check_time_full <- check_time_3 - check_time_0
 
-  print(paste0("The full computing time: ",
+  message(paste0("The full computing time: ",
                round(check_time_full, 2),
                units(check_time_full)))
 
@@ -459,9 +452,11 @@ textTrainN <- function(
 
 #### textTrainNPlot function ####
 
-#' (experimental) Plot cross-validated correlation coefficients across different
-#'  sample-sizes from the object returned by the textTrainN function. If the number
-#'  of cross-validations exceed one, then error-bars will be included in the plot.
+#' Plot cross-validated accuracies across sample sizes
+#'
+#' textTrainNPlot() plots cross-validated correlation coefficients across different
+#' sample-sizes from the object returned by the textTrainN function. If the number
+#' of cross-validations exceed one, then error-bars will be included in the plot.
 #' @param results_data (list) One or several objects returned by the function textTrainN
 #' as a list (e.g, list(object1, object2)). Also, if several models are provided,
 #' then one can add a vector c() with settings (i.e the parameters below) for each model
@@ -743,6 +738,3 @@ textTrainNPlot <- function(
   return(TrainNPlot)
 }
 
-
-
-
