@@ -8,37 +8,31 @@ context("Testing tasks")
 test_that("textClassify tests", {
   skip_on_cran()
 
-  # String example help(textClassify)
-  sen1 <- textClassify("I like you. I love you",
+  # String example help(textClassify) help(textClassify)
+  print("textClassify")
+  sen1 <- textClassifyPipe(
+    x = "I like you. I love you",
     model = "distilbert-base-uncased-finetuned-sst-2-english",
-    return_incorrect_results = TRUE,
+    force_return_results = TRUE,
     return_all_scores = FALSE,
     function_to_apply = "none"
   )
   expect_equal(sen1$score_x, 4.67502, tolerance = 0.001)
   textModelsRemove("distilbert-base-uncased-finetuned-sst-2-english")
-
-  #  # Test another model
-  sen2 <- textClassify("I like you. I love you",
-    model = "cardiffnlp/twitter-roberta-base-sentiment",
-    return_incorrect_results = TRUE, # need to set to TRUE to get results
-    return_all_scores = TRUE,
-    function_to_apply = "none"
-  )
-  textModelsRemove("cardiffnlp/twitter-roberta-base-sentiment")
   #
 })
 
 test_that("textGeneration test", {
   skip_on_cran()
 
+  print("textGeneration")
   generated_text <- textGeneration(
     x = "The meaning of life is",
     model = "gpt2",
     device = "cpu",
     tokenizer_parallelism = FALSE,
     logging_level = "warning",
-    return_incorrect_results = FALSE,
+    force_return_results = FALSE,
     return_tensors = FALSE,
     return_full_text = TRUE,
     clean_up_tokenization_spaces = FALSE,
@@ -53,13 +47,14 @@ test_that("textGeneration test", {
   expect_that(generated_text$x_generated, is_a("character"))
 
   # Return token IDs
+  print("textGeneration_2")
   generated_text2 <- text::textGeneration(
     x = "The meaning of life is",
     model = "gpt2",
     device = "cpu",
     tokenizer_parallelism = FALSE,
     logging_level = "warning",
-    return_incorrect_results = FALSE,
+    force_return_results = FALSE,
     return_tensors = TRUE,
     return_full_text = FALSE,
     clean_up_tokenization_spaces = FALSE,
@@ -76,18 +71,19 @@ test_that("textGeneration test", {
 test_that("textNER test", {
   skip_on_cran()
 
+  print("textNER")
   ner_example <- textNER("Arnes plays football with Daniel",
     mode = "dslim/bert-base-NER",
-    return_incorrect_results = FALSE
+    force_return_results = FALSE
   )
   ner_example
 
   expect_equal(ner_example$x_NER$score[1], 0.9987748, tolerance = 0.001)
 
-
+  print("textNER_2")
   ner_example2 <- textNER(Language_based_assessment_data_8[1:2, 1],
     mode = "dslim/bert-base-NER",
-    return_incorrect_results = FALSE
+    force_return_results = FALSE
   )
   ner_example2
   expect_equal(ner_example2$satisfactiontexts_NER$score[2], 0.976, tolerance = 0.01)
@@ -97,6 +93,7 @@ test_that("textNER test", {
 test_that("textSum test", {
   skip_on_cran()
 
+  print("textSum")
   sum_examples <- textSum(Language_based_assessment_data_8[1:2, 1:2],
     min_length = 2L,
     max_length = 4L
@@ -110,10 +107,14 @@ test_that("textSum test", {
 test_that("textQA test", {
   skip_on_cran()
 
+  print("textQA")
   qa_examples <- textQA(
     question = "Which colour have trees?",
     context = "Trees are mostly green and like water"
   )
+  expect_equal(qa_examples$score, .9384409, tolerance = 0.0001)
+  expect_equal(qa_examples$start, 17)
+  expect_equal(qa_examples$end, 22)
   expect_equal(qa_examples$answer, "green")
 })
 
@@ -122,6 +123,7 @@ test_that("textQA test", {
 test_that("textZeroShot test", {
   skip_on_cran()
 
+  print("textZeroShot")
   ZeroShot_example <- text::textZeroShot(
     sequences = c("I play football", "The forrest is wonderful"),
     candidate_labels = c("sport", "nature", "research"),
@@ -136,6 +138,7 @@ test_that("textZeroShot test", {
 test_that("textTranslate test", {
   skip_on_cran()
 
+  print("textTranslate")
   textModels()
   translation_example <- text::textTranslate(
     Language_based_assessment_data_8[1, 1:2],
